/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export class ChartDataItem {
  name: string;
  value: number;
  color?: string;
  description?: string;

  constructor(name: string, value: number, color?: string, description?: string) {
    this.name = name;
    this.value = value;
    this.color = color;
    this.description = description;
  }
}

export class BarChartDataSet {
  label: string;
  data: number[];
  avgUtilizationRate: number;
  backgroundColor: string;
  borderWidth: number;
  description: string[];

  constructor(label: string, data: number[], avgUtilizationRate: number, backgroundColor: string, borderWidth: number, description: string[]) {
    this.label = label;
    this.data = data;
    this.avgUtilizationRate = avgUtilizationRate;
    this.backgroundColor = backgroundColor;
    this.borderWidth = borderWidth;
    this.description = description;
  }
}
